@@ -3,7 +3,7 @@ package Acme::ID::CompanyName;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2021-05-07'; # DATE
 our $DIST = 'Acme-ID-CompanyName'; # DIST
-our $VERSION = '0.005'; # VERSION
+our $VERSION = '0.006'; # VERSION
 
 use 5.010001;
 use strict;
@@ -336,6 +336,7 @@ $SPEC{gen_generic_ind_company_names} = {
             schema => ['int*', min=>0],
             default => 1,
             cmdline_aliases => {n=>{}},
+            pos => 0,
         },
         num_words => {
             schema => ['int*', min=>1],
@@ -358,8 +359,13 @@ $SPEC{gen_generic_ind_company_names} = {
     result_naked => 1,
     examples => [
         {
-            argv => [qw/-n 2/],
-            result => [200, "OK", ["PT Sentosa Jaya Abadi", "PT Putra Utama Globalindo"]],
+            summary => 'Generate five random PT names',
+            argv => [qw/5/],
+            test => 0,
+        },
+        {
+            summary => 'Generate three PT names with desired initials "ACME"',
+            argv => [qw/-n3 --desired-initials ACME/],
             test => 0,
         },
     ],
@@ -471,7 +477,7 @@ Acme::ID::CompanyName - Generate nice-sounding, generic Indonesian company names
 
 =head1 VERSION
 
-This document describes version 0.005 of Acme::ID::CompanyName (from Perl distribution Acme-ID-CompanyName), released on 2021-05-07.
+This document describes version 0.006 of Acme::ID::CompanyName (from Perl distribution Acme-ID-CompanyName), released on 2021-05-07.
 
 =head1 DESCRIPTION
 
@@ -490,16 +496,30 @@ Examples:
 
 =over
 
-=item * Example #1:
+=item * Generate five random PT names:
 
- gen_generic_ind_company_names( num_names => 2);
+ gen_generic_ind_company_names( num_names => 5);
 
 Result:
 
  [
-   200,
-   "OK",
-   ["PT Sentosa Jaya Abadi", "PT Putra Utama Globalindo"],
+   "PT Krida Akur Tren",
+   "PT Industri Sentral Baru",
+   "PT Vita Humania Cipta",
+   "PT Cakrawalatama Central Hasil",
+   "PT Utara Ekasentralindo Cakra",
+ ]
+
+=item * Generate three PT names with desired initials "ACME":
+
+ gen_generic_ind_company_names( num_names => 3, desired_initials => "ACME");
+
+Result:
+
+ [
+   "PT Angkasatama Cipta Milenial Eka",
+   "PT Agung Chandra Milenia Eka",
+   "PT Amantama Cipta Milenial Elektronik",
  ]
 
 =back
